==> jira-projects-plugin-4.3.2.jar: sidebar/project-shortcuts/dialogs/Add-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:sidebar-project-shortcuts"], function(){
    "use strict";

    module('JIRA.Projects.Sidebar.ProjectShortcuts.Dialogs.Add', {
        setup: function () {
            this.sandbox = sinon.sandbox.create();
            this.sidebarItem = {
                $el: jQuery('<div></div>'),
                ui: {
                    link: jQuery('<div></div>')
                },
                on: sinon.stub()
            };

            this.collection = new Backbone.Collection();
            this.addDialog = new JIRA.Projects.Sidebar.ProjectShortcuts.Dialogs.Add({
                sidebarItem: this.sidebarItem,
                projectKey: "TEST",
                collection: this.collection
            });
            this.addDialog.model.clear = sinon.stub();

            this.sandbox.spy(this.addDialog.dialog, "hide");
            this.sandbox.spy(this.addDialog.dialog, "refresh");
            this.sandbox.spy(this.addDialog.view, "hideIconPicker");
        },
        teardown: function () {
            this.sandbox.restore();
        }
    });

    test('Should render view on dialog show', function () {
        this.addDialog.view.render = sinon.stub();
        this.sidebarItem.ui.link.click();
        sinon.assert.calledOnce(this.addDialog.view.render);
    });

    test('Should refresh dialog and hide picker when view renders', function () {
        this.addDialog.view.render();
        sinon.assert.calledOnce(this.addDialog.dialog.refresh);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });

    test('Should clear add-model on create', function () {
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.model.clear);
    });

    test('Should add new model to collection on create', function () {
        this.sandbox.stub(JIRA.Projects.Sidebar.ProjectShortcuts.Entities, "Shortcut");
        this.addDialog.collection.add = sinon.stub();
        this.addDialog.model.toJSON = sinon.stub().returns({
            id: 1,
            url: "test url",
            name: "test name",
            icon: "test icon"
        });
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.model.toJSON);
        sinon.assert.calledOnce(JIRA.Projects.Sidebar.ProjectShortcuts.Entities.Shortcut);
        ok(JIRA.Projects.Sidebar.ProjectShortcuts.Entities.Shortcut.calledWithNew(), "New model was created");
        deepEqual(
                JIRA.Projects.Sidebar.ProjectShortcuts.Entities.Shortcut.firstCall.args[0],
                {
                    id: 1,
                    url: "test url",
                    name: "test name",
                    icon: "test icon"
                },
                "New model was created"
        );
        sinon.assert.calledOnce(this.addDialog.collection.add);
    });

    test('Should hide dialog and picker on create', function () {
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.dialog.hide);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });

    test('Should enable callback on window resize trigger', function () {
        this.addDialog.dialog.show();
        this.addDialog.dialog.refresh.reset();
        this.addDialog.view.hideIconPicker.reset();

        jQuery(window).trigger('resize');
        sinon.assert.calledOnce(this.addDialog.dialog.refresh);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });

});

==> jira-projects-plugin-6.0.5.jar: sidebar/project-shortcuts/dialogs/Add-test.js <==
AJS.test.require(["com.atlassian.jira.jira-projects-plugin:sidebar-project-shortcuts"], function(){
    "use strict";

    var jQuery = require("jquery");
    var Backbone = require("jira-projects-backbone");
    var PSShortcut = require("jira/projects/sidebar/project-shortcuts/entities/shortcut");

    module('jira/projects/sidebar/project-shortcuts/dialogs/add', {
        setup: function () {
            this.context = AJS.test.mockableModuleContext();
            this.sandbox = sinon.sandbox.create();
            this.psShortcutModule = this.sandbox.spy(PSShortcut);
            this.context.mock("jira/projects/sidebar/project-shortcuts/entities/shortcut", this.psShortcutModule);

            var PSAddDialog = this.context.require("jira/projects/sidebar/project-shortcuts/dialogs/add");

            this.sidebarItem = {
                $el: jQuery('<div></div>'),
                ui: {
                    link: jQuery('<div></div>')
                },
                on: sinon.stub()
            };
            this.collection = new Backbone.Collection();
            this.addDialog = new PSAddDialog({
                sidebarItem: this.sidebarItem,
                projectKey: "TEST",
                collection: this.collection
            });
            this.addDialog.model.clear = sinon.stub();

            this.sandbox.spy(this.addDialog.dialog, "hide");
            this.sandbox.spy(this.addDialog.dialog, "refresh");
            this.sandbox.spy(this.addDialog.view, "hideIconPicker");
        },
        teardown: function () {
            this.sandbox.restore();
        }
    });

    test('Should render view on dialog show', function () {
        this.addDialog.view.render = sinon.stub();
        this.sidebarItem.ui.link.click();
        sinon.assert.calledOnce(this.addDialog.view.render);
    });

    test('Should refresh dialog and hide picker when view renders', function () {
        this.addDialog.view.render();
        sinon.assert.calledOnce(this.addDialog.dialog.refresh);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });

    test('Should clear add-model on create', function () {
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.model.clear);
    });

    test('Should add new model to collection on create', function () {
        this.psShortcutModule.reset();
        this.addDialog.collection.add = sinon.stub();
        this.addDialog.model.toJSON = sinon.stub().returns({
            id: 1,
            url: "test url",
            name: "test name",
            icon: "test icon"
        });
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.model.toJSON);
        sinon.assert.calledOnce(this.psShortcutModule);
        ok(this.psShortcutModule.calledWithNew(), "New model was created");
        deepEqual(
                this.psShortcutModule.firstCall.args[0],
                {
                    id: 1,
                    url: "test url",
                    name: "test name",
                    icon: "test icon"
                },
                "New model was created"
        );
        sinon.assert.calledOnce(this.addDialog.collection.add);
    });

    test('Should hide dialog and picker on create', function () {
        this.addDialog.model.trigger("save:success");
        sinon.assert.calledOnce(this.addDialog.dialog.hide);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });

    test('Should enable callback on window resize trigger', function () {
        this.addDialog.dialog.show();
        this.addDialog.dialog.refresh.reset();
        this.addDialog.view.hideIconPicker.reset();

        jQuery(window).trigger('resize');
        sinon.assert.calledOnce(this.addDialog.dialog.refresh);
        sinon.assert.calledOnce(this.addDialog.view.hideIconPicker);
    });
});
